Checkable

Trait Checkable 

pub trait Checkable {
    // Required method
    fn check_that(&self, condition: Condition) -> bool;
}
Trait for the check_that function, that allows it to run a condition on a struct.

Required Methods

fn check_that(&self, condition: Condition) -> bool

Checks whether the object satisfies the condition passed as c.

Note that the condition can be chained using .and (&) and .or (|).

Implementations on Foreign Types

Source

impl Checkable for Option<&CfgValue>

Source

fn check_that(&self, condition: Condition) -> bool

Source

impl Checkable for Option<&mut CfgValue>

Source

fn check_that(&self, condition: Condition) -> bool

Source

impl Checkable for Option<CfgValue>

Source

fn check_that(&self, condition: Condition) -> bool

Implementors