pub trait Checkable {
// Required method
fn check_that(&self, condition: Condition) -> bool;
}Expand description
Trait for the check_that function, that allows it to run a condition on a struct.
Required Methods
Sourcefn check_that(&self, condition: Condition) -> bool
fn check_that(&self, condition: Condition) -> bool
Checks whether the object satisfies the condition passed as c.
Note that the condition can be chained using .and (&) and .or (|).